from ws2812 import WS2812
import machine
import utime
import random

# Define the pins for the buttons and RGB LED
button_red = machine.Pin(28, machine.Pin.IN)
button_green = machine.Pin(29, machine.Pin.IN)
button_blue = machine.Pin(27, machine.Pin.IN)
power = machine.Pin(11,machine.Pin.OUT)
power.value(1)

# Define the color codes
RED = (255, 0, 0) #Color 0
GREEN = (0, 255, 0) #Color 1
BLUE = (0, 0, 255) #Color 2
BLACK = (0, 0, 0) #Color 3
YELLOW = (255, 255, 0)
CYAN = (0, 255, 255)
BLUE = (0, 0, 255)
PURPLE = (180, 0, 255)
WHITE = (255, 255, 255)

COLORS = (RED, GREEN, BLUE, BLACK)
START = (YELLOW, BLACK, YELLOW, BLACK, YELLOW, BLACK)
RAINBOW = (BLACK, RED, YELLOW, GREEN, CYAN, BLUE, PURPLE, WHITE)
led = WS2812(12,1) #WS2812(pin_num,led_count)

# Initialize the game variables
sequence = []
user_sequence = []
round_number = 1

def generate_sequence():
    global sequence
    addition = random.choice([0, 1, 2])
    if round_number == 1:
        sequence = [addition]
    else:
        sequence = sequence + [addition]
    return sequence
    
def display_color(color):
    led.pixels_fill(COLORS[color])
    led.pixels_show()

def play_sequence():
    for color in sequence:
        display_color(color)
        utime.sleep(1)
        display_color(3)  # Turn off the LED, display Black
        utime.sleep(0.5)

def check_user_sequence():
    if user_sequence != sequence:
        return False
    return True

while True:
   
   # Start a new round
    if round_number == 1:
        sequence = generate_sequence()
        user_sequence = []
        for color in START: 
            led.pixels_fill(color)
            led.pixels_show()
            utime.sleep(0.5)

    else:
        del user_sequence[:]
    
    utime.sleep(1)
    play_sequence()

    # Collect user input
    for i in range(1,round_number+1):
        while True:
            if button_red.value() == 1:
                user_sequence.append(0)
                break
            elif button_green.value() == 1:
                user_sequence.append(1)
                break
            elif button_blue.value() == 1:
                user_sequence.append(2)
                break
    
        utime.sleep(0.7)  # Add a small delay between button presses

    # Check if the user's sequence matches
                 
    if check_user_sequence():
        print("Round", round_number, "complete!")
    
        if round_number == 5:
            print("Congratulations! You won the game!")
            for color in RAINBOW: 
                led.pixels_fill(color)
                led.pixels_show()
                utime.sleep(0.2)
            break
        
        round_number += 1
        sequence = generate_sequence()
        
    else:
        print("Game Over! You reached round", round_number-1)
        for color in START: 
            led.pixels_fill(color)
            led.pixels_show()
            utime.sleep(0.5)
        break
